/*
		GNU GENERAL PUBLIC LICENSE
                 Version 3, 29 June 2007

 Copyright (C) 2007 Free Software Foundation, Inc. <https://fsf.org/>
 Everyone is permitted to copy and distribute verbatim copies
 of this license document, but changing it is not allowed.

 http-wokou, An HTTP Proxying framework for bypassing DNS Security
 Copyright (C) 2024 Russell Hrubesky, ChiralWorks Software LLC

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.

*/

package main

import (
	"flag"
	"fmt"
	"log"

	httpserver "git.aetherial.dev/aeth/http-proxy/pkg"
	"github.com/gin-contrib/cors"
	"github.com/gin-gonic/gin"
)

func main() {
	caching := flag.Bool("cache", false, "Supply this argument to turn on caching")
	configFile := flag.String("config", ".config", "supply the path to a configuration file for the proxy to use")
	flag.Parse()

	cfg, err := httpserver.ReadConfig(*configFile)
	if err != nil {
		log.Fatal("Couldnt read config: ", err)
	}
	cfg.Caching = *caching
	fmt.Print(cfg.Caching)

	e := gin.Default()
	config := cors.DefaultConfig()
	config.AllowOrigins = cfg.CorsHosts
	e.Use(cors.New(config))
	rmaps := httpserver.ReadRouteMap(cfg.RouteMapPath)
	httpserver.RegisterRoutes(e, cfg, rmaps)

	e.RunTLS(fmt.Sprintf("%s:%v", "0.0.0.0", cfg.HttpsPort), "/etc/letsencrypt/live/void-society.online/fullchain.pem", "/etc/letsencrypt/live/void-society.online/privkey.pem")

}
